@@ -36,20 +36,20 @@ test_that("Item Values Constraint returns errors", {
 
 
 test_that("Item Values Min Max and Threshold", {
-  minMax <- itemValuesRange(2, 2:5, range = c(3, 5), itemIDs = 1:4)
+  minMax <- itemValuesRangeConstraint(2, 2:5, range = c(3, 5), itemIDs = 1:4)
   expect_equal(minMax,
                combineConstraints(
                  itemValuesConstraint(2, 2:5, ">=", 3, itemIDs = 1:4),
                  itemValuesConstraint(2, 2:5, "<=", 5, itemIDs = 1:4)))
-  expect_equal(minMax, itemValuesDeviation(2, 2:5, 4, 1, itemIDs = 1:4))
+  expect_equal(minMax, itemValuesDeviationConstraint(2, 2:5, 4, 1, itemIDs = 1:4))
 
-  min <- itemValuesMin(3, 1:3, 2, itemIDs = 1:3)
+  min <- itemValuesMinConstraint(3, 1:3, 2, itemIDs = 1:3)
   expect_equal(min$A_binary[1,], c(1:3, rep(0, 6)))
   expect_equal(min$A_binary[3,], c(rep(0, 6), 1:3))
   expect_equal(min$operator, rep(">=", 3))
   expect_equal(min$d, rep(2, 3))
 
-  max <- itemValuesMax(3, 1:3, 4, itemIDs = 1:3)
+  max <- itemValuesMaxConstraint(3, 1:3, 4, itemIDs = 1:3)
   expect_equal(max$operator, rep("<=", 3))
   expect_equal(max$d, rep(4, 3))
 
@@ -57,7 +57,7 @@ test_that("Item Values Min Max and Threshold", {
 })
 
 test_that("Item Min Max returns error", {
-  expect_error(itemValuesRange(2, 2:5,range = c(3, 2)),
+  expect_error(itemValuesRangeConstraint(2, 2:5,range = c(3, 2)),
                "The first value of 'range' should be smaller than second value of 'range'.")
 })
 
